betty.extension.deriver package - Betty 0.4.0a3 documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.extension.deriver package

## Module contents

Expand an ancestry by deriving additional data from existing data.

final class betty.extension.deriver.Deriver

  Bases: `Extension`, `PostLoader`

  Expand an ancestry by deriving additional data from existing data.

  Parameters:

    - project (`betty.project.Project`)

    - args (`typing.Any`)

    - kwargs (`typing.Any`)

  classmethod comes_before() → set[PluginId]

    The extensions that this one comes before.

    The other extensions may or may not be enabled.

    Return type:

      `set`[`str`]

  classmethod plugin_description() → betty.locale.localizable.Localizable

    Get the human-readable long plugin description.

    Return type:

      `betty.locale.localizable.Localizable`

  classmethod plugin_id() → str

    Get the plugin ID.

    IDs are unique per plugin type: - A plugin repository MUST at most have a single plugin for any ID. - Different plugin repositories MAY each have a plugin with the same ID.

    Return type:

      `str`

  classmethod plugin_label() → betty.locale.localizable.Localizable

    Get the human-readable short plugin label.

    Return type:

      `betty.locale.localizable.Localizable`

  async post_load() → None

    Act on the ancestry having been loaded.

    This method is called immediately after `betty.load.Loader.load()`.

    Return type:

      `None`